Struct hyper_sync_rustls::ServerSession [−][src]
pub struct ServerSession { /* fields omitted */ }This represents a single TLS server session.
Send TLS-protected data to the peer using the io::Write trait implementation.
Read data from the peer using the io::Read trait implementation.
Methods
impl ServerSession[src]
impl ServerSessionⓘImportant traits for ServerSessionpub fn new(config: &Arc<ServerConfig>) -> ServerSession[src]
pub fn new(config: &Arc<ServerConfig>) -> ServerSessionMake a new ServerSession. config controls how
we behave in the TLS protocol.
pub fn get_sni_hostname(&self) -> Option<&str>[src]
pub fn get_sni_hostname(&self) -> Option<&str>Retrieves the SNI hostname, if any, used to select the certificate and private key.
This returns None until some time after the client's SNI extension
value is processed during the handshake. It will never be None when
the connection is ready to send or process application data, unless the
client does not support SNI.
This is useful for application protocols that need to enforce that the
SNI hostname matches an application layer protocol hostname. For
example, HTTP/1.1 servers commonly expect the Host: header field of
every request on a connection to match the hostname in the SNI extension
when the client provides the SNI extension.
The SNI hostname is also used to match sessions during session resumption.